@@ -60,12 +60,12 @@ EXTENSIONS = [
     "markdown.extensions.tables",
     "markdown.extensions.sane_lists",
     "markdown.extensions.admonition",
+    "markdown.extensions.md_in_html",
     "pymdownx.highlight",
     "pymdownx.inlinehilite",
     "pymdownx.magiclink",
     "pymdownx.superfences",
     "pymdownx.betterem",
-    "pymdownx.extrarawhtml",
     "pymdownx.keys",
     "pymdownx.escapeall",
     "pymdownx.smartsymbols",
